# Transpiler Mate

A small and light yet powerful Python API + CLI to extract [Schema.org/SoftwareApplication](https://schema.org/SoftwareApplication) Metadata from an annotated [CWL](https://www.commonwl.org/) document and publish it as a Record on [Invenio RDM](https://inveniosoftware.org/products/rdm/).

Read the documentation on: https://terradue.github.io/transpiler-mate/
